#version 430 core
/*
* Copyright 2019 Vienna University of Technology.
* Institute of Computer Graphics and Algorithms.
* This file is part of the ECG Lab Framework and must not be redistributed.
*/

out vec4 FragColor;

in vec2 TexCoords;
uniform vec3 colorTest;
uniform sampler2D screenTexture;
const float edgeThreshold=0.2;
uniform int width;
uniform int height;


float luminance( vec3 color ) {
    return 0.2126 * color.r + 0.7152 * color.g + 0.0722 * color.b;
}

vec4 pass1(){
    
    float dx = 1.0 / float(width);
    float dy = 1.0 / float(height);
    vec3 diffuse = texture( screenTexture, TexCoords + vec2(-dx,dy) ).rgb;
    float s00 = luminance(texture( screenTexture, TexCoords + vec2(-dx,dy) ).rgb);
    float s10 = luminance(texture( screenTexture, TexCoords + vec2(-dx,0.0) ).rgb);
    float s20 = luminance(texture( screenTexture, TexCoords + vec2(-dx,-dy) ).rgb);
    float s01 = luminance(texture( screenTexture, TexCoords + vec2(0.0,dy) ).rgb);
    float s21 = luminance(texture( screenTexture, TexCoords + vec2(0.0,-dy) ).rgb);
    float s02 = luminance(texture( screenTexture, TexCoords + vec2(dx, dy) ).rgb);
    float s12 = luminance(texture( screenTexture, TexCoords + vec2(dx, 0.0) ).rgb);
    float s22 = luminance(texture( screenTexture, TexCoords + vec2(dx, -dy) ).rgb);

    float sx = s00 + 2 * s10 + s20 - (s02 + 2 * s12 + s22);
    float sy = s00 + 2 * s01 + s02 - (s20 + 2 * s21 + s22);

    float dist = sx * sx + sy * sy;

    if( dist > edgeThreshold ){
        return vec4(0.0,0.0,0.0,1.0);
    }
    else {
       return vec4(diffuse,1.0);
    }

}


void main()
{	


	FragColor=pass1();
} 
